@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Id: acconfig.h,v 1.5 2002/04/03 08:37:02 bazsi Exp $
+ * $Id: acconfig.h,v 1.6.4.2 2004/05/06 08:57:52 bazsi Exp $
  *
  * Copyright (c) 1999 BalaBit Computing
  * 
@@ -40,4 +40,9 @@
 #undef PATH_SYSCONFDIR 
 
 #undef ENABLE_TCP_WRAPPER
- 
\ No newline at end of file
+
+#undef HAVE_RES_INIT
+
+#undef ENABLE_SPOOF_SOURCE 
+
+#undef HAVE_GLOBAL_TIMEZONE
