@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.61.4.1 2004/01/13 18:08:02 bazsi Exp $
+ * $Id: affile.c,v 1.61.4.2 2004/05/06 08:38:27 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -512,6 +512,15 @@ affile_find_writer(struct affile_dest *self,
 	}
 
 	expanded_fname = expand_macros(self->cfg, self->template_fname, 0, msg);
+	if (self->flags & AFFILE_SANITIZE_FILENAMES) {
+		int i;
+		
+		for (i = 0; i < expanded_fname->length; i++) {
+			if (expanded_fname->data[i] < 32) {
+				expanded_fname->data[i] = '.';
+			}
+		}
+	}
 	p = self->writers;
 	while (p && 
 	       ((p->expanded_fname->length != expanded_fname->length) || 
@@ -561,6 +570,8 @@ do_init_affile_dest(struct log_handler *c,
 		self->dir_gid = cfg->dir_gid;
 	if (self->dir_perm == -1)
 		self->dir_perm = cfg->dir_perm;
+	if (cfg->sanitize_filenames)
+		self->flags |= AFFILE_SANITIZE_FILENAMES;
 	
 	self->cfg = cfg;
 	return ST_OK | ST_GOON;
