@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afstreams.c,v 1.16 2003/01/20 15:28:35 bazsi Exp $
+ * $Id: afstreams.c,v 1.16.4.1 2004/03/10 18:43:28 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -40,6 +40,7 @@
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
+#include <alloca.h>
 
 #if HAVE_SUN_DOOR && HAVE_DOOR_H
 #include <door.h>
@@ -78,6 +79,7 @@ static struct door_fd *make_door_fd(int fd)
      (super nonblocking_fd)
      (vars
        (bad_hostname special-struct regex_t #f regfree)
+       (max_log_line . UINT32)
        (pipe object log_handler)))
 */
 
@@ -118,11 +120,11 @@ static int do_stream_read(int fd, UINT32 *pri, UINT32 length, UINT8 *buf)
 static void stream_read_callback(struct nonblocking_fd *fd)
 {
 	CAST(stream_fd, self, fd);
-	char line[MAX_LINE*10];
+	char *line = alloca(self->max_log_line + 1);
 	UINT32 pri;
 	int n;
 	
-	n = do_stream_read(self->super.fd, &pri, sizeof(line), line);
+	n = do_stream_read(self->super.fd, &pri, self->max_log_line, line);
 	if (n < 0) {
 		close_fd(fd, CLOSE_EOF);
 		return;
@@ -136,6 +138,17 @@ static void stream_read_callback(struct nonblocking_fd *fd)
 		bol = line;
 		eol = memchr(bol, '\n', n);
 		if (!eol) eol = memchr(bol, '\0', n);
+		
+		if (!eol) {
+		
+			/* FIXME: there must be space for this '\0' as we
+			 * specified sizeof(buf) - 1 when reading the message
+			 */
+			
+			eol = &line[n];
+			line[n] = '\0';
+			n++;
+		}
 
 		while (eol) {
 
